from django.core.management import BaseCommand

from django_email_foundation.api import DjangoEmailFoundation, Checks


class Command(BaseCommand):
    help = 'Create the necessary folders inside the template path and it add a basic layout.'

    def handle(self, *args, **options):
        checks = Checks()
        if not checks.templates_source_path():
            self.stdout.write(self.style.ERROR('You must to define the templates source path.'))
            return

        self.stdout.write('Creating folders...')
        engine = DjangoEmailFoundation()
        error = engine.create_basic_structure()

        if error:
            self.stderr.write(self.style.ERROR(error))
        else:
            self.stdout.write(self.style.SUCCESS('Done!'))



import os
import pytest

from django_email_foundation.utils import get_relative_from_manage_path


@pytest.mark.parametrize(
    'getcwd,path,expected',
    [
        ('/home/demo/workspace/my_project/src', 'src/module/emails', 'module/emails'),
        ('/home/demo/workspace/my_project', 'module/emails', 'module/emails'),
        ('/home/demo/workspace/my_project/src', 'src/emails/sources', 'emails/sources'),
        ('/home/demo/workspace/my_project', 'test/emails/sources', 'test/emails/sources'),
    ]
)
def test_get_relative_from_manage_path(getcwd, path, expected, monkeypatch):
    def getcwd_patched():
        return getcwd
    monkeypatch.setattr(os, 'getcwd', getcwd_patched)
    assert get_relative_from_manage_path(path) == expected
